[![image](/images/f5_logo.png)](https://github.com/yangsec888/f5-admin)
=====================
- [To Do List](#to-do-list)

---

## To Do List
Some of the nice features I can think of are listed below. If you have any other idea, please ping me directly at [yangsec888@gmail.com](mailto:yangsec888@gmail.com)

* Upgrade to Python 3 - Done
* More unit tests - Done
* Implement [F5 Object Dependency Tree Resolving algorithm](/TREE.md) - Done
* Web interface for the common utilities - TBD
* Others - TBD
